@@ -19,19 +19,19 @@ int main(int argc, char *argv[])
 {
         QApplication app(argc, argv);
 
-	Kdelibs4ConfigMigrator migrate(QLatin1String("kgeography"));
-	migrate.setConfigFiles(QStringList() << QLatin1String("kgeographyrc"));
-	migrate.setUiFiles(QStringList() << QLatin1String("kgeographyui.rc"));
+	Kdelibs4ConfigMigrator migrate(QStringLiteral("kgeography"));
+	migrate.setConfigFiles(QStringList() << QStringLiteral("kgeographyrc"));
+	migrate.setUiFiles(QStringList() << QStringLiteral("kgeographyui.rc"));
 	migrate.migrate();
 	KLocalizedString::setApplicationDomain("kgeography");
 
-	KAboutData about("kgeography", i18n("KGeography"), "0.9", i18n("A Geography learning program"), KAboutLicense::GPL, i18n("© 2004-2005 Albert Astals Cid"), QString(), "http://userbase.kde.org/KGeography");
-	about.addAuthor(i18n("Albert Astals Cid"), i18n("Programmer and designer"), "aacid@kde.org");
-	about.addCredit(i18n("Sodipodi flags collection"), i18n("Got some flags from it"), 0, "http://www.sodipodi.com/index.php3?section=clipart/flags");
+	KAboutData about(QStringLiteral("kgeography"), i18n("KGeography"), QStringLiteral("0.9"), i18n("A Geography learning program"), KAboutLicense::GPL, i18n("© 2004-2005 Albert Astals Cid"), QString(), QStringLiteral("http://userbase.kde.org/KGeography"));
+	about.addAuthor(i18n("Albert Astals Cid"), i18n("Programmer and designer"), QStringLiteral("aacid@kde.org"));
+	about.addCredit(i18n("Sodipodi flags collection"), i18n("Got some flags from it"), 0, QStringLiteral("http://www.sodipodi.com/index.php3?section=clipart/flags"));
 
 	KAboutData::setApplicationData(about);
 
-        app.setWindowIcon(QIcon::fromTheme(QLatin1String("kgeography")));
+        app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kgeography")));
 
 	QCommandLineParser parser;
 	about.setupCommandLine(&parser);
